@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: libraries.lisp 10608 2005-07-01 00:39:48Z kevin $
+;;;; $Id: libraries.lisp 10811 2005-11-07 17:54:11Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
@@ -76,8 +76,8 @@ library type if type is not specified."
 
 (defun load-foreign-library (filename &key module supporting-libraries
 					   force-load)
-  #+(or allegro mcl) (declare (ignore module supporting-libraries))
-  #+(or cmu scl sbcl) (declare (ignore module))
+  #+(or allegro mcl sbcl) (declare (ignore module supporting-libraries))
+  #+(or cmu scl) (declare (ignore module))
   #+lispworks (declare (ignore supporting-libraries))
 
   (when (and filename (or (null (pathname-directory filename))
@@ -86,8 +86,8 @@ library type if type is not specified."
 	(setq filename (namestring (if (null (pathname-directory filename))
 				       filename 
 				       ;; lispworks treats as UNC, so use truename
-				       #+(and lispworks win32 mswindows) (truename filename)
-				       #-(and lispworks win32 mswindows) filename))))
+				       #+(and lispworks win32) (truename filename)
+				       #-(and lispworks win32) filename))))
     
     (if (and (not force-load)
 	     (find filename *loaded-libraries* :test #'string-equal))
