@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: objects.lisp 10608 2005-07-01 00:39:48Z kevin $
+;;;; $Id: objects.lisp 10756 2005-09-18 07:23:45Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
@@ -242,6 +242,12 @@ an array of TYPE with size SIZE. The TYPE parameter is evaluated."
   '(error "WITH-CAST-POINTER not (yet) implemented for ~A"
           (lisp-implementation-type)))
 
+#+(or allegro openmcl)
+(defun convert-external-name (name) 
+  "Add an underscore to NAME if necessary for the ABI."
+  #+(or macosx darwinppc-target) (concatenate 'string "_" name)
+  #-(or macosx darwinppc-target) name)
+
 (defmacro def-foreign-var (names type module)
   #-lispworks (declare (ignore module))
   (let ((foreign-name (if (atom names) names (first names)))
@@ -255,7 +261,7 @@ an array of TYPE with size SIZE. The TYPE parameter is evaluated."
     #+allegro
     `(define-symbol-macro ,lisp-name
       (ff:fslot-value-typed (quote ,(convert-from-uffi-type type :deref))
-                            :c (ff:get-entry-point ,foreign-name)))
+                            :c (ff:get-entry-point ,(convert-external-name foreign-name))))
     #+lispworks
     `(progn
       (fli:define-foreign-variable (,lisp-name ,foreign-name)
@@ -264,11 +270,10 @@ an array of TYPE with size SIZE. The TYPE parameter is evaluated."
                                     :module ,module)
       (define-symbol-macro ,lisp-name (fli:dereference (,lisp-name)
                                                         :copy-foreign-object nil)))
-    #+(and openmcl darwinppc-target)
-    (setf foreign-name (concatenate 'string "_" foreign-name))
     #+openmcl
     `(define-symbol-macro ,lisp-name
-       (deref-pointer (ccl:foreign-symbol-address ,foreign-name) ,var-type))
+       (deref-pointer (ccl:foreign-symbol-address
+                       ,(convert-external-name foreign-name)) ,var-type))
     #-(or allegro cmu scl sbcl lispworks openmcl)
     `(define-symbol-macro ,lisp-name
       '(error "DEF-FOREIGN-VAR not (yet) defined for ~A"
