@@ -63,6 +63,7 @@
    #:convert-to-foreign-string
    #:allocate-foreign-string
    #:with-foreign-string
+   #:with-foreign-strings
    #:foreign-string-length
    
    ;; function call
@@ -76,6 +77,7 @@
 
    ;; OS
    #:run-shell-command
+   #:getenv
    ))
 
 
